/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Sales **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Sales'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:58+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Russian (http://www.transifex.com/tine20/tine20/language/ru/)\nLanguage: ru\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Either postalcode or postbox is required!"
: "Необходимо указать почтовый индекс или почтовый ящик!"

, "Copy Supplier"
: "Копировать поставщика"

, "Add New Supplier"
: "Добавить нового поставщика"

, "Edit Supplier \"{0}\""
: "Редактировать поставщика \"{0}\""

, "Copy address to the clipboard"
: "Скопировать адрес в буфер обмена"

, "Supplier, Suppliers"
: [
  ""
 ,""
 ,""
 ,""

]
, "Core Data"
: ""

, "Supplier Number"
: "Номер поставщика"

, "Name"
: "Название"

, "Contact Person (external)"
: "Контактное лицо (внешнее)"

, "Contact Person (internal)"
: "Контактное лицо (внутреннее)"

, "Accounting"
: ""

, "VAT ID"
: ""

, "Credit Term (days)"
: "Срок оплаты (дней)"

, "Currency"
: "Валюта"

, "Currency Translation Rate"
: "Курс валюты"

, "IBAN"
: "IBAN"

, "BIC"
: "BIC"

, "Postal Address"
: "Почтовый адрес"

, "Street"
: "Улица"

, "Postbox"
: ""

, "Postalcode"
: "Почтовый индекс"

, "Locality"
: "Местонахождение"

, "Region"
: "Область"

, "Country"
: "Страна"

, "Prefix"
: ""

, "Additional Prefix"
: ""

, "Miscellaneous"
: ""

, "Web"
: "Сайт"

, "Description"
: "Описание"

, "Enter description"
: "Введите описание"

, "total"
: ""

, "inclusive"
: ""

, "exceeding"
: ""

, "Create timesheet"
: ""

, "Create Reversal Invoice"
: ""

, "Copy Invoice"
: "Копировать счёт"

, "Add New Invoice"
: "Добавить новый счёт"

, "Edit Invoice \"{0}\""
: ""

, "Positions ({0})"
: ""

, "No customer assigned"
: "Не указан клиент"

, "The selected contract doesn't have a customer assigned, yet. Add a customer to the contract with the contract edit dialog."
: ""

, "No cost center assigned"
: ""

, "The selected contract doesn't have a cost center assigned, yet. Add a cost center to the contract with the contract edit dialog."
: ""

, "Price Net"
: ""

, "Taxes (VAT)"
: ""

, "Price Gross"
: ""

, "Sales Tax (percent)"
: ""

, "Inventory Change"
: ""

, "Invoice, Invoices"
: [
  ""
 ,""
 ,""
 ,""

]
, "Invoice Number"
: "Номер счёта"

, "automatically set..."
: "автоматически установлено..."

, "Date"
: "Дата"

, "Type"
: "Тип"

, "Contract, Contracts"
: [
  "Договор"
 ,"Договора"
 ,"Договоров"
 ,"Договоров"

]
, "Customer, Customers"
: [
  "Клиент"
 ,"Клиента"
 ,"Клиентов"
 ,"Клиенты"

]
, "Billing Address"
: "Адрес для выставления счетов"

, "Credit Term"
: "Срок оплаты"

, "Cleared"
: "Просчитано"

, "Interval Begins"
: "Период начинается"

, "Interval Ends"
: "Период заканчивается"

, "Select invoice"
: "Выберите счёт"

, "Total Price"
: "Итоговая цена"

, "Cancel"
: "Отмена"

, "OK"
: "OK"

, "Loading..."
: "Загрузка..."

, "Euro (€)"
: "Евро (€)"

, "Order Confirmation, Order Confirmations"
: [
  ""
 ,""
 ,""
 ,""

]
, "without order confirmation"
: ""

, "Number"
: "Число"

, "Title"
: "Заголовок"

, "Billing Addresses"
: "Адреса для выставления счетов"

, "Delivery Address"
: "Адрес доставки"

, "Delivery Addresses"
: "Адреса доставки"

, "Edit {0} \"{1}\""
: "Редактировать {0} \"{1}\""

, "Add New Billing Address"
: ""

, "Add New Delivery Address"
: ""

, "Apply postal address"
: ""

, "Number Debit"
: ""

, "Address, Addresss"
: [
  "Адрес"
 ,"Адреса"
 ,"Адресов"
 ,"Адреса"

]
, "without customer"
: "без клиента"

, "Copy Purchase Invoice"
: ""

, "Add New Purchase Invoice"
: ""

, "Edit Purchase Invoice \"{0}\""
: ""

, "Date of invoice"
: "Дата счёта"

, "Due in"
: "Оплата через "

, "Due date"
: "Дата оплаты"

, "Additional Price Gross"
: ""

, "Discount (%)"
: "Скидка (%)"

, "Purchase Invoice, Purchase Invoices"
: [
  ""
 ,""
 ,""
 ,""

]
, "Overdue date"
: "Дата просрочки"

, "Discount until"
: "Скидка до"

, "Dun date"
: ""

, "Payed at"
: "Оплачено"

, "Method of payment"
: "Способ оплаты"

, "Approver"
: ""

, "Lead Cost Center"
: ""

, "Add New Offer"
: "Добавить новое предложение"

, "Clipboard"
: "Буфер обмена"

, "Product, Products"
: [
  "Продукт"
 ,"Продукты"
 ,"Продукты"
 ,"Продукты"

]
, "Quantity"
: "Количество"

, "Interval"
: "Интервал"

, "Billing Point"
: ""

, "begin"
: ""

, "end"
: ""

, "Start Date"
: "Дата начала"

, "End Date"
: "Дата окончания"

, "Attributes"
: ""

, "Last Autobill"
: ""

, "Creation Time"
: "Дата создания"

, "Created By"
: "Создано"

, "Last Modified Time"
: "Дата последнего изменения"

, "Last Modified By"
: ""

, "Edit Attributes"
: ""

, "Attribute"
: ""

, "Value"
: ""

, "Add a New Value..."
: ""

, "without contract"
: "без контракта"

, "Add New Order Confirmation"
: ""

, "Offer, Offers"
: [
  ""
 ,""
 ,""
 ,""

]
, "Add New Product"
: "Добавить новый продукт"

, "Product Number"
: ""

, "GTIN"
: ""

, "Category"
: "Категория"

, "Manufacturer"
: "Производитель"

, "Purchaseprice"
: ""

, "Salesprice"
: ""

, "Lifespan start"
: ""

, "Lifespan end"
: ""

, "Enter description..."
: "Ввести описание..."

, "Accountable"
: ""

, "Selected  {0}"
: ""

, "Select customer"
: ""

, "Customer Number"
: "Номер клиента"

, "Products"
: ""

, "Rebilling Invoice..."
: ""

, "Rebill Invoice"
: ""

, "Merge Invoices"
: ""

, "Select supplier"
: "Выбрать поставщика"

, "Add New Cost Center"
: ""

, "Remark"
: "Примечание"

, "without supplier"
: "без поставщика"

, "Add New Division"
: "Добавить новое подразделение"

, "Bill Contract"
: ""

, "Billing Contract..."
: ""

, "Bill Contract \"{0} - {1}\""
: ""

, "Select the date to generate the bill for"
: ""

, "Either street or postbox is required!"
: ""

, "Copy Customer"
: ""

, "Add New Customer"
: ""

, "Edit Customer \"{0}\""
: ""

, "Name shorthand"
: ""

, "Set as accountable"
: ""

, "Choose product for accountable"
: ""

, "Please use a decimal number here!"
: "Пожалуйста, используйте десятичные цифры!"

, "Positions"
: ""

, "Ok"
: "Ok"

, "Export Records from these Positions"
: ""

, "without approver"
: ""

, "Auto Invoice Contract Interval"
: ""

, "Sets the biggest interval, contracts will be billed."
: ""

, "Ignore Billables Before Date"
: ""

, "Sets the date billables will be ignored before."
: ""

, "Contract Number Creation"
: "Создание номера контракта"

, "Should the contract number be set manually or be auto-created?"
: "Задать номер контракта в ручную или создать автоматически?"

, "automatically"
: "автоматически"

, "manually"
: "в ручную"

, "Contract Number Validation"
: "Проверка номера контракта"

, "The Number can be validated as text or number."
: "Номер должен быть проверен как текст или число"

, "Text"
: "Текст"

, "Own Currency"
: ""

, "The currency defined here is used as default currency in the customerd edit dialog."
: ""

, "Invoice Type"
: ""

, "Possible Invoice Types."
: ""

, "Reversal"
: ""

, "Credit"
: "Кредит"

, "Product Category"
: ""

, "Possible Product Categories."
: ""

, "Default"
: "По-умолчанию"

, "Product Number Creation"
: ""

, "Should the product number be set manually or be auto-created?"
: ""

, "Product Number Validation"
: ""

, "Product Number Prefix"
: ""

, "The prefix of the product number."
: ""

, "Product Number Zero Fill"
: ""

, "Fill the number with leading zero"
: ""

, "Payment Method"
: ""

, "Possible Payment Methods."
: ""

, "Bank transfer"
: ""

, "Direct debit"
: ""

, "Cancellation"
: ""

, "Credit card"
: "Кредитная карта"

, "EC card"
: ""

, "Paypal"
: "Paypal"

, "Assets"
: ""

, "Invoice Cleared"
: ""

, "Possible Invoice Cleared States."
: ""

, "to clear"
: "очистить"

, "cleared"
: "очищено"

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Offers Module"
: ""

, "Order Confirmations Module"
: ""

, "Suppliers Module"
: "Модуль управления поставщиками"

, "Purchase Invoice Module"
: ""

, "You do not have admin rights on Sales"
: "У вас нет административных прав на Продажи"

, "Number duplicate"
: ""

, "The number you tried to use has been taken already. Please use another one leave the field blank to take the next free number."
: ""

, "Following Invoices Found"
: ""

, "There is an invoice for the same contract after this one. Please delete the following invoice(s) before deleting this one!"
: ""

, "Address as Billing Address in Use"
: ""

, "The Address you tried to delete is used in one or more contract(s) as Billing Address. Please assign another Billing Address to these contracts or change this one and do not delete."
: ""

, "Invoice is cleared already"
: ""

, "The Invoice you tried to delete is cleared already, so deleting is not possible anymore!"
: ""

, "No Right to alter the Number"
: ""

, "You are not allowed to alter the number afterwards!"
: ""

, "The Invoice you tried to edit is cleared already, so no editing is possible anymore!"
: ""

, "Unknown Currency Code"
: ""

, "The Currency Code you tried to use is not valid. Please use a valid Currency Code as defined in ISO 4217."
: ""

, "Invoice Timesheet"
: ""

, "CLEARED"
: ""

, "INVOICE"
: ""

, "GENDER_Cost Center"
: ""

, "Cost Center, Cost Centers"
: [
  ""
 ,""
 ,""
 ,""

]
, "GENDER_Offer"
: ""

, "GENDER_Invoice"
: ""

, "Sales Tax"
: ""

, "Reversal Invoice"
: ""

, "Invoice Item"
: ""

, "Is active"
: ""

, "GENDER_Contract"
: ""

, "Merge"
: ""

, "Responsible"
: "Ответственный"

, "Partner"
: "Партнёр"

, "Time Account"
: "Временный счет"

, "GENDER_Customer)recordsName"
: ""

, "GENDER_Order Confirmation"
: ""

, "GENDER_Supplier"
: ""

, "GENDER_Division"
: ""

, "Division, Divisions"
: [
  "Подразделение"
 ,"Подразделения"
 ,"Подразделения"
 ,"Подразделения"

]
, "Billing Interval"
: ""

, "Piece"
: ""

, "GENDER_Address"
: ""

, "Due at"
: ""

, "Invoice Position, Invoice Positions"
: [
  ""
 ,""
 ,""
 ,""

]
, "Month"
: "Месяц"

, "Unit"
: ""

, "The number you have tried to set is already in use!"
: "Число, которое вы пытались установить, уже используется!"

, "My Products"
: "Мои продукты"

, "Products created by me"
: ""

, "My Contracts"
: "Мои контракты"

, "Contracts created by myself"
: "Созданные мной контракты"

, "All Customers"
: ""

, "All customer records"
: ""

, "All Offers"
: ""

, "All offer records"
: ""

, "Inactive Contracts"
: ""

, "Contracts that have already been terminated"
: ""

, "Active Contracts"
: ""

, "Contracts that are still running"
: ""

, "All Suppliers"
: "Все поставщики"

, "All supllier records"
: ""

, "All Purchase Imvoices"
: ""

, "All purchase invoices"
: ""

, "All Products"
: "Все продукты"

, "All product records"
: ""

, "All Contracts"
: "Все контакты"

, "All contract records"
: ""

, "All Invoices"
: ""

, "All invoice records"
: ""

, "All Cost Centers"
: ""

, "All costcenter records"
: ""

, "All Divisions"
: ""

, "All division records"
: ""

, "All Order Confirmations"
: ""

, "All order confirmation records"
: ""

, "You have to set a customer!"
: ""

, "Manage Products"
: ""

, "Add, edit and delete products."
: ""

, "Manage Contracts"
: ""

, "Add, edit and delete contracts."
: ""

, "Manage Cost Centers"
: ""

, "Add, edit and delete cost centers."
: ""

, "Manage Customers"
: ""

, "Add, edit and delete customers."
: ""

, "Manage Suppliers"
: ""

, "Add, edit and delete suppliers."
: ""

, "manage invoices"
: "управление счетами"

, "Add, edit and delete invoices."
: ""

, "Manage Divisions"
: ""

, "Add, edit and delete divisions."
: ""

, "Manage Order Confirmations"
: ""

, "Add, edit and delete order confirmations."
: ""

, "Manage Offers"
: ""

, "Add, edit and delete offers."
: ""

, "Manage Purchase Invoices"
: ""

, "Add, edit and delete purchase invoices."
: ""

, "Change number of an order confirmations"
: ""

, "Allow changing the number of an order confirmation during the update."
: ""

, "Set number of invoices"
: ""

, "Allow to set the number of an invoice."
: ""











, "Supplier"
: ""

, "Invoice"
: ""

, "Contract"
: "Договор"

, "Customer"
: "Клиент"

, "Order Confirmation"
: ""

, "Address"
: "Адрес"

, "Purchase Invoice"
: ""

, "Product"
: "Продукт"

, "Offer"
: ""

, "Cost Center"
: ""

, "Division"
: "Подразделение"

, "Invoice Position"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
